You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tapestry.apache.org by jk...@apache.org on 2006/11/14 07:02:30 UTC

svn commit: r474671 [2/3] - in /tapestry/tapestry4/trunk: ./ .settings/ tapestry-annotations/src/java/org/apache/tapestry/annotations/ tapestry-annotations/src/test/org/apache/tapestry/annotations/ tapestry-contrib/src/java/org/apache/tapestry/contrib/...

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/ITemplateSourceDelegate.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/ITemplateSourceDelegate.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/ITemplateSourceDelegate.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/ITemplateSourceDelegate.java Mon Nov 13 22:02:23 2006
@@ -36,7 +36,7 @@
 public interface ITemplateSourceDelegate
 {
     /**
-     *  Invoked by the {@link ITemplateSource} when a template can't be found
+     *  Invoked by the {@link ITemplateSourceDelegate} when a template can't be found
      *  by normal means (i.e., in the normal locations).  This method
      *  should find the template.  The result may be null.  The delegate
      *  is responsible for caching the result.

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycle.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycle.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycle.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycle.java Mon Nov 13 22:02:23 2006
@@ -19,6 +19,7 @@
 import java.util.Map;
 import java.util.Stack;
 
+import org.apache.commons.fileupload.RequestContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.hivemind.ApplicationRuntimeException;
@@ -29,6 +30,7 @@
 import org.apache.tapestry.IComponent;
 import org.apache.tapestry.IEngine;
 import org.apache.tapestry.IForm;
+import org.apache.tapestry.IMarkupWriter;
 import org.apache.tapestry.IPage;
 import org.apache.tapestry.IRender;
 import org.apache.tapestry.IRequestCycle;

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycleEnvironment.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycleEnvironment.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycleEnvironment.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/engine/RequestCycleEnvironment.java Mon Nov 13 22:02:23 2006
@@ -21,7 +21,8 @@
 
 /**
  * An object that contains all the invariant parameters to the
- * {@link org.apache.tapestry.engine.RequestCycle#RequestCycle(IEngine, QueryParameterMap, IEngineService, IMonitor, RequestCycleEnvironment)}
+ * 
+ * {@link RequestCycle#RequestCycle(org.apache.tapestry.IEngine, org.apache.tapestry.util.QueryParameterMap, String, RequestCycleEnvironment)}
  * constructor.
  * 
  * @author Howard M. Lewis Ship

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/enhance/InjectRenderWorker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/enhance/InjectRenderWorker.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/enhance/InjectRenderWorker.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/enhance/InjectRenderWorker.java Mon Nov 13 22:02:23 2006
@@ -21,7 +21,7 @@
 
 /**
  * Injects the component's render worker chain as the
- * {@link org.apache.tapestry.IComponent#getRenderWorker() renderWorker}property.
+ * {@link org.apache.tapestry.IComponent renderWorker}property.
  * 
  * @author jkuhnert
  * @since 4.1

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/event/BrowserEvent.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/event/BrowserEvent.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/event/BrowserEvent.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/event/BrowserEvent.java Mon Nov 13 22:02:23 2006
@@ -106,7 +106,8 @@
     
     /**
      * Returns the target of the client side event.
-     * @return
+     * 
+     * @return The target representation of the client side object event originally bound for.
      */
     public EventTarget getTarget()
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/Form.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/Form.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/Form.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/Form.java Mon Nov 13 22:02:23 2006
@@ -14,6 +14,7 @@
 
 package org.apache.tapestry.form;
 
+import org.apache.hivemind.ApplicationRuntimeException;
 import org.apache.hivemind.Location;
 import org.apache.tapestry.AbstractComponent;
 import org.apache.tapestry.IActionListener;
@@ -150,7 +151,7 @@
      * JavaScript and need to access the form or its contents.
      * <p>
      * This value is generated when the form renders, and is not cleared. If the Form is inside a
-     * {@link org.apache.tapestry.components.Foreach}, this will be the most recently generated
+     * {@link org.apache.tapestry.components.ForBean}, this will be the most recently generated
      * name for the Form.
      * <p>
      * This property is exposed so that sophisticated applications can write JavaScript handlers for

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/FormComponentContributorContext.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/FormComponentContributorContext.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/FormComponentContributorContext.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/FormComponentContributorContext.java Mon Nov 13 22:02:23 2006
@@ -14,8 +14,11 @@
 
 package org.apache.tapestry.form;
 
+import org.apache.tapestry.FormBehavior;
 import org.apache.tapestry.IComponent;
 import org.apache.tapestry.json.JSONObject;
+import org.apache.tapestry.util.RegexpMatcher;
+import org.apache.tapestry.valid.ValidationConstants;
 
 /**
  * Object that provides support to objects that implement
@@ -23,7 +26,7 @@
  * about client-side JavaScript generation.
  * <p>
  * TODO: Having support for regular expressions might be useful (and would allow a single
- * {@link RegexpMatcher to be shared).
+ * {@link RegexpMatcher to be shared}).
  * 
  * @author Howard Lewis Ship
  * @since 4.0

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/IFormComponent.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/IFormComponent.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/IFormComponent.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/IFormComponent.java Mon Nov 13 22:02:23 2006
@@ -37,7 +37,7 @@
      * Returns the name of the component, which is automatically generated during renderring.
      * <p>
      * This value is set inside the component's render method and is <em>not</em> cleared. If the
-     * component is inside a {@link org.apache.tapestry.components.Foreach}, the value returned is
+     * component is inside a {@link org.apache.tapestry.components.ForBean}, the value returned is
      * the most recent name generated for the component.
      * <p>
      * This property is made available to facilitate writing JavaScript that allows components (in

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ListEdit.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ListEdit.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ListEdit.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ListEdit.java Mon Nov 13 22:02:23 2006
@@ -28,7 +28,7 @@
 
 /**
  * A specialized component used to edit a list of items within a form; it is similar to a
- * {@link org.apache.tapestry.components.Foreach}but leverages hidden inputs within the
+ * {@link org.apache.tapestry.components.ForBean} but leverages hidden inputs within the
  * &lt;form&gt; to store the items in the list. [ <a
  * href="../../../../../ComponentReference/ListEdit.html">Component Reference </a>]
  * 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/PropertySelection.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/PropertySelection.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/PropertySelection.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/PropertySelection.java Mon Nov 13 22:02:23 2006
@@ -29,10 +29,10 @@
  * 2.3.
  * <p>
  * Typically, the values available to be selected are defined using an
- * {@link org.apache.commons.lang.enum.Enum}. A PropertySelection is dependent on an
+ * {@link java.lang.Enum}. A PropertySelection is dependent on an
  * {@link IPropertySelectionModel} to provide the list of possible values.
  * <p>
- * Often, this is used to select a particular {@link org.apache.commons.lang.enum.Enum} to assign to
+ * Often, this is used to select a particular {@link java.lang.Enum} to assign to
  * a property; the {@link EnumPropertySelectionModel} class simplifies this.
  * <p>
  * Often, a drop-down list will contain an initial option that serves both as a label and to represent 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/TranslatedFieldSupport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/TranslatedFieldSupport.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/TranslatedFieldSupport.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/TranslatedFieldSupport.java Mon Nov 13 22:02:23 2006
@@ -20,7 +20,6 @@
 
 /**
  * 
- * @author unknown
  */
 public interface TranslatedFieldSupport
 {
@@ -29,7 +28,6 @@
      * Formats the field translation.
      * @param field
      * @param object
-     * @return
      */
     String format(TranslatedField field, Object object);
 
@@ -37,7 +35,7 @@
      * Parses the field value.
      * @param field
      * @param text
-     * @return
+     * 
      * @throws ValidatorException
      */
     Object parse(TranslatedField field, String text)

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupport.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupport.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupport.java Mon Nov 13 22:02:23 2006
@@ -16,10 +16,11 @@
 
 import org.apache.tapestry.IMarkupWriter;
 import org.apache.tapestry.IRequestCycle;
+import org.apache.tapestry.form.validator.Required;
 import org.apache.tapestry.valid.ValidatorException;
 
 /**
- * Implements the logic used by {@link RequiredField}s for required field checking on rewind and
+ * Implements the logic used by {@link Required}s for required field checking on rewind and
  * generating client-side logic during render.
  * 
  * @author Paul Ferraro

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupportImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupportImpl.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupportImpl.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/ValidatableFieldSupportImpl.java Mon Nov 13 22:02:23 2006
@@ -24,7 +24,7 @@
 import org.apache.tapestry.valid.ValidatorException;
 
 /**
- * Default {@link VadidatableFieldSupport} implementation. This implementation generates calls to a
+ * Default {@link ValidatableFieldSupport} implementation. This implementation generates calls to a
  * static javascript function during render if client-side validation is enabled.
  * 
  * @author Paul Ferraro
@@ -52,7 +52,7 @@
     }
 
     /**
-     * @see org.apache.tapestry.form.ValidatableFieldSupport#renderValidatorContributions(org.apache.tapestry.form.ValidatableField, org.apache.tapestry.IMarkupWriter, org.apache.tapestry.IRequestCycle)
+     * @see org.apache.tapestry.form.ValidatableFieldSupport#renderContributions(ValidatableField, IMarkupWriter, IRequestCycle)
      */
     public void renderContributions(ValidatableField component, IMarkupWriter writer,
             IRequestCycle cycle)

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/AbstractTranslator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/AbstractTranslator.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/AbstractTranslator.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/AbstractTranslator.java Mon Nov 13 22:02:23 2006
@@ -108,8 +108,7 @@
     }
 
     /**
-     * @see org.apache.tapestry.form.FormComponentContributor#renderContribution(org.apache.tapestry.IRequestCycle,
-     *      org.apache.tapestry.form.IFormComponent)
+     * @see org.apache.tapestry.form.FormComponentContributor#renderContribution(IMarkupWriter, IRequestCycle, FormComponentContributorContext, IFormComponent)
      */
     public void renderContribution(IMarkupWriter writer, IRequestCycle cycle,
             FormComponentContributorContext context, IFormComponent field)

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/Translator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/Translator.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/Translator.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/form/translator/Translator.java Mon Nov 13 22:02:23 2006
@@ -18,6 +18,7 @@
 
 import org.apache.tapestry.form.FormComponentContributor;
 import org.apache.tapestry.form.IFormComponent;
+import org.apache.tapestry.form.ValidatableField;
 import org.apache.tapestry.form.ValidationMessages;
 import org.apache.tapestry.valid.ValidatorException;
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/html/Shell.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/html/Shell.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/html/Shell.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/html/Shell.java Mon Nov 13 22:02:23 2006
@@ -269,7 +269,8 @@
 
     /**
      * Include additional content in the header of a page.
-     * @param style 
+     * 
+     * @param content 
      *
      * @since 4.1.1
      */
@@ -277,11 +278,14 @@
     {
         if (HiveMind.isBlank(content))
             return;
+        
         StringBuffer buffer = getContentBuffer();
+        
         if (buffer == null)
             buffer = new StringBuffer();
         
-        buffer.append(content);        
+        buffer.append(content);
+        
         setContentBuffer(buffer);
     }
     

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/ComponentEventProperty.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/ComponentEventProperty.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/ComponentEventProperty.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/ComponentEventProperty.java Mon Nov 13 22:02:23 2006
@@ -110,7 +110,8 @@
      * creates a new instance if one doesn't exist already.
      * 
      * @param event
-     * @return
+     * 
+     * @return The current set of listeners bound to the specified event.
      */
     public List getEventListeners(String event)
     {
@@ -128,7 +129,9 @@
      * creates a new instance if one doesn't exist already.
      * 
      * @param event
-     * @return
+     * 
+     * @return The current set of listeners that will submit a form bound to the
+     *          specified event.
      */
     public List getFormEventListeners(String event)
     {
@@ -152,7 +155,8 @@
     
     /**
      * The set of all form based listener events.
-     * @return
+     * 
+     * @return All mapped form event keys.
      */
     public Set getFormEvents()
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/EventBoundListener.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/EventBoundListener.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/EventBoundListener.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/internal/event/EventBoundListener.java Mon Nov 13 22:02:23 2006
@@ -98,7 +98,8 @@
     /**
      * Whether or not listener should submit form
      * asynchronously.
-     * @return
+     * 
+     * @return True if listener is asynchronous.
      */
     public boolean isAsync()
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/IJSONWriter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/IJSONWriter.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/IJSONWriter.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/IJSONWriter.java Mon Nov 13 22:02:23 2006
@@ -21,7 +21,7 @@
  * participating in a particular response to decide how to cooperate and build
  * a JSON structure that their client side will accept.
  * 
- * @see <a href="http://www.json.org/">http://www.json.org/</a>
+ * @see "http://www.json.org/"
  * @author JSON.org, jkuhnert
  */
 public interface IJSONWriter

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/JSONObject.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/JSONObject.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/JSONObject.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/json/JSONObject.java Mon Nov 13 22:02:23 2006
@@ -254,9 +254,6 @@
         this(new JSONTokener(string));
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONObject accumulate(String key, Object value)
     {
         JSONArray a;
@@ -276,9 +273,6 @@
         return this;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public Object get(String key)
     {
         Object o = opt(key);
@@ -287,9 +281,6 @@
         return o;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public boolean getBoolean(String key)
     {
         Object o = get(key);
@@ -306,9 +297,6 @@
                 + "] is not a Boolean.");
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public double getDouble(String key)
     {
         Object o = get(key);
@@ -328,9 +316,6 @@
         return this.myHashMap;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public int getInt(String key)
     {
         Object o = get(key);
@@ -338,9 +323,6 @@
                 : (int) getDouble(key);
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONArray getJSONArray(String key)
     {
         Object o = get(key);
@@ -349,9 +331,6 @@
                 + "] is not a JSONArray.");
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONObject getJSONObject(String key)
     {
         Object o = get(key);
@@ -360,49 +339,31 @@
                 + "] is not a JSONObject.");
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public String getString(String key)
     {
         return get(key).toString();
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public boolean has(String key)
     {
         return this.myHashMap.containsKey(key);
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public boolean isNull(String key)
     {
         return JSONObject.NULL.equals(opt(key));
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public Iterator keys()
     {
         return this.myHashMap.keySet().iterator();
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public int length()
     {
         return this.myHashMap.size();
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONArray names()
     {
         JSONArray ja = new JSONArray();
@@ -446,26 +407,17 @@
         return s;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public Object opt(String key)
     {
         if (key == null) { throw new NullPointerException("Null key"); }
         return this.myHashMap.get(key);
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public boolean optBoolean(String key)
     {
         return optBoolean(key, false);
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public boolean optBoolean(String key, boolean defaultValue)
     {
         Object o = opt(key);
@@ -484,17 +436,11 @@
         return defaultValue;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public double optDouble(String key)
     {
         return optDouble(key, Double.NaN);
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public double optDouble(String key, double defaultValue)
     {
         Object o = opt(key);
@@ -513,17 +459,11 @@
         return defaultValue;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public int optInt(String key)
     {
         return optInt(key, 0);
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public int optInt(String key, int defaultValue)
     {
         Object o = opt(key);
@@ -542,53 +482,35 @@
         return defaultValue;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONArray optJSONArray(String key)
     {
         Object o = opt(key);
         return o instanceof JSONArray ? (JSONArray) o : null;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONObject optJSONObject(String key)
     {
         Object o = opt(key);
         return o instanceof JSONObject ? (JSONObject) o : null;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public String optString(String key)
     {
         return optString(key, "");
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public String optString(String key, String defaultValue)
     {
         Object o = opt(key);
         return o != null ? o.toString() : defaultValue;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONObject put(String key, boolean value)
     {
         put(key, Boolean.valueOf(value));
         return this;
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONObject put(String key, double value)
     {
         put(key, new Double(value));
@@ -601,18 +523,12 @@
         return this;
     }
     
-    /** 
-     * {@inheritDoc}
-     */
     public JSONObject put(String key, int value)
     {
         put(key, new Integer(value));
         return this;
     }
-
-    /** 
-     * {@inheritDoc}
-     */
+    
     public JSONObject put(String key, Object value)
     {
         if (key == null) { throw new NullPointerException("Null key."); }
@@ -626,10 +542,7 @@
         }
         return this;
     }
-
-    /** 
-     * {@inheritDoc}
-     */
+    
     public JSONObject putOpt(String key, Object value)
     {
         if (value != null)
@@ -640,9 +553,10 @@
     }
 
     /**
-     * @see {{@link #quote(String)}.
+     * @see #quote(String) .
      * @param value
-     * @return
+     * 
+     * @return The character quoted.
      */
     public static String quote(char value)
     {
@@ -718,17 +632,11 @@
         return sb.toString();
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public Object remove(String key)
     {
         return this.myHashMap.remove(key);
     }
 
-    /** 
-     * {@inheritDoc}
-     */
     public JSONArray toJSONArray(JSONArray names)
     {
         if (names == null || names.length() == 0) { return null; }
@@ -762,10 +670,7 @@
         sb.append('}');
         return sb.toString();
     }
-
-    /** 
-     * {@inheritDoc}
-     */
+    
     public String toString(int indentFactor)
     {
         return toString(indentFactor, 0);

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/link/ServiceLink.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/link/ServiceLink.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/link/ServiceLink.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/link/ServiceLink.java Mon Nov 13 22:02:23 2006
@@ -20,9 +20,8 @@
 
 /**
  *  A component for creating a link for an arbitrary {@link org.apache.tapestry.engine.IEngineService
- *  engine service}.  A ServiceLink component can emulate an {@link ActionLink},
- *  {@link PageLink} or {@link DirectLink} component, but is most often used in
- *  conjunction with an application-specific service.  
+ *  engine service}.  A ServiceLink component can emulate a {@link PageLink} or {@link DirectLink} component, 
+ *  but is most often used in conjunction with an application-specific service.  
  *
  *  [<a href="../../../../../ComponentReference/ServiceLink.html">Component Reference</a>]
  *

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerInvokerTerminator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerInvokerTerminator.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerInvokerTerminator.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerInvokerTerminator.java Mon Nov 13 22:02:23 2006
@@ -39,8 +39,6 @@
      *            the listener. Not generally used, but may not be null.
      * @param cycle
      *            the current request cycle, to be passed to the listener.
-     * @param delegate
-     *            the next invoker in the pipeline
      */
     public void invokeListener(IActionListener listener, IComponent source,
             IRequestCycle cycle)

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerMap.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerMap.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerMap.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/listener/ListenerMap.java Mon Nov 13 22:02:23 2006
@@ -16,6 +16,7 @@
 
 import java.util.Collection;
 
+import org.apache.hivemind.ApplicationRuntimeException;
 import org.apache.tapestry.IActionListener;
 
 /**

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/markup/JSONWriterImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/markup/JSONWriterImpl.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/markup/JSONWriterImpl.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/markup/JSONWriterImpl.java Mon Nov 13 22:02:23 2006
@@ -98,7 +98,8 @@
     /**
      * The outputstream being used to write this 
      * instance's content.
-     * @return 
+     * 
+     * @return  The writer being written to.
      */
     protected PrintWriter getWriter()
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/pageload/PageSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/pageload/PageSource.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/pageload/PageSource.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/pageload/PageSource.java Mon Nov 13 22:02:23 2006
@@ -35,7 +35,7 @@
  * unique key (usually built from the application name).
  * <p>
  * The <code>PageSource</code> acts as a pool for {@link IPage}instances. Pages are retrieved
- * from the pool using {@link #getPage(IRequestCycle, String, IMonitor)}and are later returned to
+ * from the pool using {@link #getPage(IRequestCycle, String)}and are later returned to
  * the pool using {@link #releasePage(IPage)}.
  * <p>
  * TBD: Pooled pages stay forever. Need a strategy for cleaning up the pool, tracking which pages

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/ITemplateParserDelegate.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/ITemplateParserDelegate.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/ITemplateParserDelegate.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/ITemplateParserDelegate.java Mon Nov 13 22:02:23 2006
@@ -33,9 +33,6 @@
     /**
      * Returns true if the specified component allows a body, false otherwise. The parser uses this
      * information to determine if it should ignore the body of a tag.
-     * 
-     * @throws org.apache.tapestry.ApplicationRuntimeException
-     *             if no such component exists
      */
 
     boolean getAllowBody(String componentId, Location location);
@@ -47,8 +44,6 @@
      *            the specified library id, possibly null
      * @param type
      *            the component type
-     * @throws org.apache.tapestry.ApplicationRuntimeException
-     *             if the specification cannot be found
      * @since 3.0
      */
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/SpecificationParser.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/SpecificationParser.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/SpecificationParser.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/parse/SpecificationParser.java Mon Nov 13 22:02:23 2006
@@ -128,7 +128,7 @@
             + IDENTIFIER_PATTERN + "/)*" + IDENTIFIER_PATTERN + "$";
 
     /**
-     * Extended version of {@link Tapestry.SIMPLE_PROPERTY_NAME_PATTERN}, but allows a series of
+     * Extended version of {@link Tapestry#SIMPLE_PROPERTY_NAME_PATTERN}, but allows a series of
      * individual property names, seperated by periods. In addition, each name within the dotted
      * sequence is allowed to contain dashes.
      * 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/record/ClientPropertyPersistenceScope.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/record/ClientPropertyPersistenceScope.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/record/ClientPropertyPersistenceScope.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/record/ClientPropertyPersistenceScope.java Mon Nov 13 22:02:23 2006
@@ -67,7 +67,7 @@
      * Extracts a page name from a query parameter name.
      * 
      * @param parameterName
-     *            the paramter name, for which {@link #isParameterForScope(String) must return true
+     *            the paramter name, for which {@link #isParameterForScope(String)} must return true
      * @return the name of the page
      */
     String extractPageName(String parameterName);

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/AbstractSpecificationResolver.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/AbstractSpecificationResolver.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/AbstractSpecificationResolver.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/AbstractSpecificationResolver.java Mon Nov 13 22:02:23 2006
@@ -59,8 +59,7 @@
     }
 
     /**
-     * Returns the {@link ISpecificationResolverDelegate}instance registered in the application
-     * specification as extension {@link Tapestry#SPECIFICATION_RESOLVER_DELEGATE_EXTENSION_NAME},
+     * Returns the {@link ISpecificationResolverDelegate}instance registered in the application 
      * or null if no such extension exists.
      */
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolver.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolver.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolver.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolver.java Mon Nov 13 22:02:23 2006
@@ -14,6 +14,7 @@
 
 package org.apache.tapestry.resolver;
 
+import org.apache.hivemind.ApplicationRuntimeException;
 import org.apache.hivemind.Location;
 import org.apache.tapestry.INamespace;
 import org.apache.tapestry.IRequestCycle;
@@ -47,7 +48,7 @@
 
     /**
      * Like
-     * {@link #resolve(org.apache.tapestry.IRequestCycle, org.apache.tapestry.INamespace, java.lang.String, org.apache.tapestry.ILocation)},
+     * {@link #resolve(org.apache.tapestry.IRequestCycle, org.apache.tapestry.INamespace, java.lang.String, Location)},
      * but used when the type has already been parsed into a library id and a simple type.
      * 
      * @param cycle

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolverImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolverImpl.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolverImpl.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/resolver/ComponentSpecificationResolverImpl.java Mon Nov 13 22:02:23 2006
@@ -114,7 +114,7 @@
 
     /**
      * Like
-     * {@link #resolve(org.apache.tapestry.IRequestCycle, org.apache.tapestry.INamespace, java.lang.String, org.apache.tapestry.ILocation)},
+     * {@link #resolve(org.apache.tapestry.IRequestCycle, org.apache.tapestry.INamespace, java.lang.String, Location)},
      * but used when the type has already been parsed into a library id and a simple type.
      * 
      * @param cycle

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/AbstractTokenRule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/AbstractTokenRule.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/AbstractTokenRule.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/AbstractTokenRule.java Mon Nov 13 22:02:23 2006
@@ -46,11 +46,8 @@
     }
 
     /**
-     * Peeks at the top object on the stack (which must be a {@link IScriptToken}),
-     * and converts the text into a series of {@link org.apache.tapestry.script.StaticToken} and
-     * {@link org.apache.tapestry.script.InsertToken}s.
+     * {@inheritDoc}
      */
-
     public void content(RuleDirectedParser parser, String content)
     {
         IScriptToken token = (IScriptToken) parser.peek();

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/BodyRule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/BodyRule.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/BodyRule.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/BodyRule.java Mon Nov 13 22:02:23 2006
@@ -18,7 +18,7 @@
 import org.xml.sax.Attributes;
 
 /**
- * Constructs a {@link org.apache.tapestry.script.BodyToken} from
+ * Constructs a {@link BodyToken} from
  * a &lt;body&gt; element, which contains full content.
  *
  * @author Howard Lewis Ship

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/InsertToken.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/InsertToken.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/InsertToken.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/script/InsertToken.java Mon Nov 13 22:02:23 2006
@@ -14,6 +14,9 @@
 
 package org.apache.tapestry.script;
 
+import java.io.Writer;
+import java.util.Map;
+
 import org.apache.hivemind.Location;
 
 /**

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ApplicationGlobals.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ApplicationGlobals.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ApplicationGlobals.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ApplicationGlobals.java Mon Nov 13 22:02:23 2006
@@ -24,7 +24,7 @@
 
 /**
  * A "global" holder for various services and configurations. In many cases, these values end up as
- * properties of the {@link org.apache.tapestry.services.Infrastructure}. The servlet and portlet
+ * properties of the {@link org.apache.tapestry.services.Infrastructure} . The servlet and portlet
  * implementations differentiate themselves by storing different values into these properties.
  * 
  * @author Howard Lewis Ship
@@ -54,7 +54,7 @@
     /**
      * Returns the previously stored context.
      * 
-     * @see #store(WebContext)}.
+     * @see #storeWebContext(WebContext) .
      */
 
     WebContext getWebContext();
@@ -74,7 +74,7 @@
 
     /**
      * Stores the default set of engine service definitions. Application services override factory
-     * services with the same {@link org.apache.tapestry.engine.IEngineService#getName()name}.
+     * services with the same {@link org.apache.tapestry.engine.IEngineService#getName()} .
      * 
      * @param factoryServices
      *            List of {@link org.apache.tapestry.engine.IEngineService}.

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentConstructorFactory.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentConstructorFactory.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentConstructorFactory.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentConstructorFactory.java Mon Nov 13 22:02:23 2006
@@ -35,7 +35,7 @@
      *            the page or component specification which directs the enhancement operation
      * @param className
      *            the name of the base component class (in some cases,
-     *            {@link IComponentSpecification#getComponentClassName() is null andother code
+     *            {@link IComponentSpecification#getComponentClassName()} is null andother code
      *            provides the default)
      * @returns a constructor used to create instances of the enhanced component class
      */

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentRenderWorker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentRenderWorker.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentRenderWorker.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ComponentRenderWorker.java Mon Nov 13 22:02:23 2006
@@ -15,6 +15,7 @@
 
 import org.apache.tapestry.IComponent;
 import org.apache.tapestry.IRequestCycle;
+import org.apache.tapestry.PageRenderSupport;
 import org.apache.tapestry.html.Body;
 
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/DataSqueezerFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/DataSqueezerFilter.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/DataSqueezerFilter.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/DataSqueezerFilter.java Mon Nov 13 22:02:23 2006
@@ -27,7 +27,7 @@
     String squeeze(Object data, DataSqueezer dataSqueezer);
 
     /**
-     * A convenience; invokes {@link #squeeze(Object)}for each element in the
+     * A convenience; invokes {@link #squeeze(Object, DataSqueezer)}for each element in the
      * data array. If data is null, returns null.
      * @param data the data to squeeze
      * @param dataSqueezer the next squeezer in the pipeline

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/RequestLocaleManager.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/RequestLocaleManager.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/RequestLocaleManager.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/RequestLocaleManager.java Mon Nov 13 22:02:23 2006
@@ -30,8 +30,7 @@
 
     /**
      * Determines the locale to use for processing the current request. The
-     * value is returned, but also stored as
-     * {@link org.apache.tapestry.services.RequestGlobals#setIncomingLocale(Locale)}.
+     * value is returned, but also stored as locale.
      */
 
     Locale extractLocaleForCurrentRequest();

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseBuilder.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseBuilder.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseBuilder.java Mon Nov 13 22:02:23 2006
@@ -19,6 +19,8 @@
 import org.apache.tapestry.IMarkupWriter;
 import org.apache.tapestry.IRender;
 import org.apache.tapestry.IRequestCycle;
+import org.apache.tapestry.PageRenderSupport;
+import org.apache.tapestry.services.impl.DojoAjaxResponseBuilder;
 
 /**
  * Represents the service responsible for managing all content output that is sent
@@ -82,7 +84,8 @@
     /**
      * Implementors that manage content writes dynamically (ie {@link DojoAjaxResponseBuilder}) should
      * return true to denote that dynamic behaviour is on for a particular response.
-     * @return
+     * 
+     * @return Whether or not request is dynamic.
      */
     boolean isDynamic();
     

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseContributor.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseContributor.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseContributor.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseContributor.java Mon Nov 13 22:02:23 2006
@@ -44,7 +44,8 @@
      * 
      * @param cycle
      *          The incoming request cycle for this request.
-     * @return
+     *          
+     * @return A newly created response builder.
      */
     ResponseBuilder createBuilder(IRequestCycle cycle)
     throws IOException;

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseDelegateFactory.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseDelegateFactory.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ServiceConstants.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ServiceConstants.java Mon Nov 13 22:02:23 2006
@@ -35,7 +35,7 @@
 
     /**
      * The id path to the component within the page. By convention, this component is within the
-     * {@link #PAGE}, unless {@link #CONTAINER_PAGE}&nbsp;is specified.
+     * {@link #PAGE}.
      */
 
     public static final String COMPONENT = "component";

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/TemplateSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/TemplateSource.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/TemplateSource.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/TemplateSource.java Mon Nov 13 22:02:23 2006
@@ -63,9 +63,6 @@
      *  @param cycle The request cycle loading the template; this is required
      *  in some cases when the template is loaded from an {@link org.apache.tapestry.IAsset}.
      *  @param component The component for which a template should be loaded.
-     *
-     *  @throws org.apache.tapestry.ApplicationRuntimeException if the resource cannot be located or loaded.
-     * 
      */
 
     ComponentTemplate getTemplate(IRequestCycle cycle, IComponent component);

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ApplicationSpecificationInitializer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ApplicationSpecificationInitializer.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ApplicationSpecificationInitializer.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ApplicationSpecificationInitializer.java Mon Nov 13 22:02:23 2006
@@ -29,8 +29,7 @@
 import org.apache.tapestry.web.HttpServletWebActivator;
 
 /**
- * Locates the application specification and informs the
- * {@link org.apache.tapestry.services.ServletInfo}service about it.
+ * Locates the application specification and informs the servlet service about it.
  * 
  * @author Howard Lewis Ship
  * @since 4.0

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventConnectionWorker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventConnectionWorker.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventConnectionWorker.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventConnectionWorker.java Mon Nov 13 22:02:23 2006
@@ -303,7 +303,8 @@
      * @param prop
      * @param scriptParms
      * @param cycle
-     * @return
+     * 
+     * @return A set of events that can be connected "now".
      */
     Object[][] filterFormEvents(ComponentEventProperty prop, Map scriptParms, IRequestCycle cycle)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventInvoker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventInvoker.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventInvoker.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentEventInvoker.java Mon Nov 13 22:02:23 2006
@@ -114,7 +114,7 @@
     }
     
     /**
-     * Causes the configured listeners for the passed {@link FormSupport}'s {@link IForm) to
+     * Causes the configured listeners for the passed {@link FormSupport}'s {@link IForm} to
      * be invoked, if mapped to this request/event.
      * 
      * @param formSupport
@@ -296,7 +296,8 @@
     
     /**
      * Returns the {@link Map} being managed for element events.
-     * @return
+     * 
+     * @return The map of events to elements.
      */
     public Map getElementEvents()
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentTemplateLoaderImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentTemplateLoaderImpl.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentTemplateLoaderImpl.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ComponentTemplateLoaderImpl.java Mon Nov 13 22:02:23 2006
@@ -15,6 +15,7 @@
 package org.apache.tapestry.services.impl;
 
 import org.apache.commons.logging.Log;
+import org.apache.tapestry.IRender;
 import org.apache.tapestry.IRequestCycle;
 import org.apache.tapestry.ITemplateComponent;
 import org.apache.tapestry.binding.BindingSource;

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderFactory.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderFactory.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderFactory.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderFactory.java Mon Nov 13 22:02:23 2006
@@ -16,12 +16,13 @@
 
 import org.apache.hivemind.ServiceImplementationFactory;
 import org.apache.hivemind.ServiceImplementationFactoryParameters;
+import org.apache.hivemind.internal.Module;
 import org.apache.hivemind.schema.Translator;
 
 /**
  * A special-purpose factory for constructing the
- * {@link org.apache.tapestry.services.InjectedValueProvider}service (which needs access to a
- * {@link org.apache.hivemind.Module}which is normally not visible.
+ * {@link org.apache.tapestry.services.InjectedValueProvider} service (which needs access to a
+ * {@link Module} which is normally not visible.
  * 
  * @author Howard M. Lewis Ship
  * @since 4.0

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderImpl.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderImpl.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/InjectedValueProviderImpl.java Mon Nov 13 22:02:23 2006
@@ -42,7 +42,7 @@
     
     /**
      * Deletegates out to
-     * {@link Translator#translate(org.apache.hivemind.internal.Module, java.lang.Class, java.lang.String, org.apache.hivemind.Location).
+     * {@link Translator#translate(org.apache.hivemind.internal.Module, java.lang.Class, java.lang.String, org.apache.hivemind.Location)} .
      */
     public Object obtainValue(String locator, Location location)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedPropertySource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedPropertySource.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedPropertySource.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedPropertySource.java Mon Nov 13 22:02:23 2006
@@ -24,7 +24,7 @@
  * Wraps around a {@link org.apache.tapestry.engine.IPropertySource}to query a series of localized
  * keys.
  * <p>
- * This is much simpler than the old {@link org.apache.tapestry.util.LocalizedPropertySource}, and
+ * This is much simpler than the old {@link LocalizedPropertySource}, and
  * allows the locale to be specified on a thread-safe, per-invocation basis.
  * 
  * @author Howard M. Lewis Ship
@@ -47,7 +47,7 @@
      * 
      * @param propertyName
      *            the base property name to search with.
-     * @param local
+     * @param locale
      *            the Locale used to generate suffixes (may be null).
      */
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedStringRender.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedStringRender.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedStringRender.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/LocalizedStringRender.java Mon Nov 13 22:02:23 2006
@@ -23,6 +23,7 @@
 import org.apache.tapestry.IRender;
 import org.apache.tapestry.IRequestCycle;
 import org.apache.tapestry.parse.LocalizationToken;
+import org.apache.tapestry.parse.TextToken;
 
 /**
  * A class used with invisible localizations. Constructed from a {@link TextToken}.

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ResponseDelegateFactoryImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ResponseDelegateFactoryImpl.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ResponseDelegateFactoryImpl.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/ResponseDelegateFactoryImpl.java Mon Nov 13 22:02:23 2006
@@ -54,7 +54,7 @@
      * Sets a configured list of {@link ResponseContributor} objects to be used
      * in processing ajax requests.
      * 
-     * @param invokers
+     * @param responseContributors
      */
     public void setResponseContributors(List responseContributors)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SpecificationSourceImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SpecificationSourceImpl.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SpecificationSourceImpl.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SpecificationSourceImpl.java Mon Nov 13 22:02:23 2006
@@ -40,7 +40,7 @@
  * Default implementation of {@link ISpecificationSource} that expects to use the normal class
  * loader to locate component specifications from within the classpath.
  * <p>
- * Caches specifications in memory forever, or until {@link #resetDidOccur()} is invoked.
+ * Caches specifications in memory forever, or until {@link #resetEventDidOccur()} is invoked.
  * 
  * @author Howard Lewis Ship
  */
@@ -159,7 +159,7 @@
     /**
      * Gets a component specification.
      * 
-     * @param resourcePath
+     * @param resourceLocation
      *            the complete resource path to the specification.
      * @throws ApplicationRuntimeException
      *             if the specification cannot be obtained.

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySource.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySource.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySource.java Mon Nov 13 22:02:23 2006
@@ -33,7 +33,7 @@
     }
 
     /**
-     * Invokes {@link Module#getSymbolValue(java.lang.String)}.
+     * Invokes {@link Module#getConfigurationAsMap(String)}.
      */
     public String getPropertyValue(String propertyName)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySourceFactory.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySourceFactory.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySourceFactory.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/impl/SymbolSourcesPropertySourceFactory.java Mon Nov 13 22:02:23 2006
@@ -16,11 +16,12 @@
 
 import org.apache.hivemind.ServiceImplementationFactory;
 import org.apache.hivemind.ServiceImplementationFactoryParameters;
+import org.apache.hivemind.internal.Module;
 
 /**
  * Used to create an service instance of
  * {@link  org.apache.tapestry.services.impl.SymbolSourcesPropertySource}. This is because SSPS
- * needs an instance of {@link org.apache.hivemind.Module}, and there's no way to do that
+ * needs an instance of {@link Module}, and there's no way to do that
  * with hivemind.BuilderFactory.
  * 
  * @author Howard Lewis Ship

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/ComponentSpecification.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/ComponentSpecification.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/ComponentSpecification.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/ComponentSpecification.java Mon Nov 13 22:02:23 2006
@@ -333,7 +333,7 @@
      * Returns the specification of a parameter with the given name, or null if no such parameter
      * exists.
      * 
-     * @see #addParameter(String, IParameterSpecification)
+     * @see #addParameterByName(String, IParameterSpecification)
      */
 
     public IParameterSpecification getParameter(String name)
@@ -370,7 +370,7 @@
     /**
      * Returns a List of of String names of all parameters. This list is in alphabetical order.
      * 
-     * @see #addParameter(String, IParameterSpecification)
+     * @see #addParameterByName(String, IParameterSpecification)
      */
 
     public List getParameterNames()

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IComponentSpecification.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IComponentSpecification.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IComponentSpecification.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IComponentSpecification.java Mon Nov 13 22:02:23 2006
@@ -138,7 +138,7 @@
      * Returns the specification of a parameter with the given name, or null if
      * no such parameter exists.
      * 
-     * @see #addParameter(String, IParameterSpecification)
+     * @see #addParameter(IParameterSpecification)
      */
     IParameterSpecification getParameter(String name);
 
@@ -156,7 +156,7 @@
      * Returns a List of of String names of all parameters. This list is in
      * alphabetical order.
      * 
-     * @see #addParameter(String, IParameterSpecification)
+     * @see #addParameter(IParameterSpecification)
      */
     List getParameterNames();
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IPropertySpecification.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IPropertySpecification.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IPropertySpecification.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/IPropertySpecification.java Mon Nov 13 22:02:23 2006
@@ -17,10 +17,7 @@
 import org.apache.hivemind.LocationHolder;
 
 /**
- * Defines a transient or persistant property of a component or page. A
- * {@link org.apache.tapestry.enhance.ComponentClassFactory}uses this
- * information to create a subclass with the necessary instance variables and
- * methods.
+ * Defines a transient or persistant property of a component or page.
  * 
  * @author glongman@intelligentworks.com
  */

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/LocatablePropertyHolder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/LocatablePropertyHolder.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/LocatablePropertyHolder.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/spec/LocatablePropertyHolder.java Mon Nov 13 22:02:23 2006
@@ -21,7 +21,7 @@
 /**
  * Base class for implementing both interfaces
  * {@link org.apache.tapestry.util.IPropertyHolder} and
- * {@link org.apache.tapestry.ILocationHolder}. This is used by all the
+ * {@link LocationHolder}. This is used by all the
  * specification classes.
  * 
  * @author Howard Lewis Ship

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/test/MockComponentRenderWorker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/test/MockComponentRenderWorker.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/test/MockComponentRenderWorker.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/test/MockComponentRenderWorker.java Mon Nov 13 22:02:23 2006
@@ -13,6 +13,7 @@
 // limitations under the License.
 package org.apache.tapestry.test;
 
+import org.apache.tapestry.AbstractComponent;
 import org.apache.tapestry.IComponent;
 import org.apache.tapestry.IRequestCycle;
 import org.apache.tapestry.html.Body;

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/Strftime.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/Strftime.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/Strftime.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/Strftime.java Mon Nov 13 22:02:23 2006
@@ -29,7 +29,7 @@
  * Added to tapestry in order to help with dojo/javascript date/time conversions.
  * </p>
  * 
- * @see {@linkplain http://www.opengroup.org/onlinepubs/007908799/xsh/strftime.html}
+ * @see "http://www.opengroup.org/onlinepubs/007908799/xsh/strftime.html"
  * @author Bip Thelin
  * @author Dan Sandberg
  */
@@ -191,7 +191,7 @@
     /**
      * Parses the input. 
      * 
-     * @see {@link java.text.SimpleDateFormat#parse(String)}
+     * @see java.text.SimpleDateFormat#parse(String)
      * @param input The string to parse.
      * @return A parsed {@link Date}.
      * @throws ParseException On input error.
@@ -215,7 +215,7 @@
     /**
      * Change the timezone used to format dates.
      * 
-     * @see SimpleDateFormat#setTimeZone
+     * @see SimpleDateFormat#setTimeZone(TimeZone)
      */
     public void setTimeZone(TimeZone timeZone)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/io/SqueezeAdaptor.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/io/SqueezeAdaptor.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/io/SqueezeAdaptor.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/io/SqueezeAdaptor.java Mon Nov 13 22:02:23 2006
@@ -43,17 +43,12 @@
     /**
      * Converts the data object into a String.
      * 
-     * @throws IOException
-     *             if the object can't be converted.
      */
 
     String squeeze(DataSqueezer squeezer, Object data);
 
     /**
      * Converts a String back into an appropriate object.
-     * 
-     * @throws IOException
-     *             if the String can't be converted.
      */
 
     Object unsqueeze(DataSqueezer squeezer, String string);

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/AsciiCharacterTranslator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/AsciiCharacterTranslator.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/AsciiCharacterTranslator.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/AsciiCharacterTranslator.java Mon Nov 13 22:02:23 2006
@@ -55,7 +55,7 @@
     }
 
     /**
-     * @see org.apache.tapestry.util.text.ICharacterTranslator#translate(char).
+     * @see org.apache.tapestry.util.text.ICharacterTranslator#translate(char) .
      */
     public String translate(char ch)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/MarkupCharacterTranslator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/MarkupCharacterTranslator.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/MarkupCharacterTranslator.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/text/MarkupCharacterTranslator.java Mon Nov 13 22:02:23 2006
@@ -68,7 +68,7 @@
     }
 
     /**
-     * @see org.apache.tapestry.util.text.IMarkupCharacterTranslator#translateAttribute(char)
+     * @see ICharacterTranslator#translate(char)
      */
     public String translate(char ch)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/xml/RuleDirectedParser.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/xml/RuleDirectedParser.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/xml/RuleDirectedParser.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/util/xml/RuleDirectedParser.java Mon Nov 13 22:02:23 2006
@@ -43,7 +43,7 @@
 import org.xml.sax.helpers.DefaultHandler;
 
 /**
- * A simplified version of {@link org.apache.commons.digester.Digester}. This version is without as
+ * A simplified version of org.apache.commons.digester.Digester. This version is without as
  * many bells and whistles but has some key features needed when parsing a document (rather than a
  * configuration file): <br>
  * <ul>
@@ -189,7 +189,7 @@
     }
 
     /**
-     * Returns an {@link ILocation}representing the current position within the document (depending
+     * Returns an {@link Location}representing the current position within the document (depending
      * on the parser, this may be accurate to column number level).
      */
 
@@ -340,7 +340,7 @@
     }
 
     /**
-     * Uses the {@link Locator}to track the position in the document as a {@link ILocation}. This
+     * Uses the {@link Locator}to track the position in the document as a {@link Location}. This
      * is invoked once (before the initial element is parsed) and the Locator is retained and
      * queried as to the current file location.
      * 
@@ -361,7 +361,7 @@
     }
 
     /**
-     * Pops the top rule off the stack and invokes {@link IRule#endElementt(RuleDirectedParser)}.
+     * Pops the top rule off the stack and invokes {@link IRule#endElement(RuleDirectedParser)}.
      */
     public void endElement(String uri, String localName, String qName) throws SAXException
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/IValidationDelegate.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/IValidationDelegate.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/IValidationDelegate.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/IValidationDelegate.java Mon Nov 13 22:02:23 2006
@@ -21,11 +21,12 @@
 import org.apache.tapestry.IRender;
 import org.apache.tapestry.IRequestCycle;
 import org.apache.tapestry.form.IFormComponent;
+import org.apache.tapestry.form.TextField;
 
 /**
  * Interface used to track validation errors in forms and
  * {@link IFormComponent form element component}s (including
- * {@link org.apache.tapestry.form.AbstractTextField}&nbsp;and its subclasses).
+ * {@link TextField}&nbsp;and its subclasses).
  * <p>
  * In addition, controls how fields that are in error are presented (they can be
  * <em>decorated</em> in various ways by the delegate; the default
@@ -55,7 +56,7 @@
  * errors, some of which are associated with a particular field, some of which
  * are unassociated with any particular field.
  * <p>
- * But what happens if you use a {@link org.apache.tapestry.components.Foreach}&nbsp;or
+ * But what happens if you use a {@link org.apache.tapestry.components.ForBean}&nbsp;or
  * {@link org.apache.tapestry.form.ListEdit}&nbsp;inside your form? Some of
  * your components will render multiple times. In this case you will have
  * multiple <em>fields</em>. Each field will have a unique field name (the

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidField.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidField.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidField.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidField.java Mon Nov 13 22:02:23 2006
@@ -18,6 +18,7 @@
 import org.apache.tapestry.IRequestCycle;
 import org.apache.tapestry.Tapestry;
 import org.apache.tapestry.form.AbstractFormComponent;
+import org.apache.tapestry.form.Form;
 
 /**
  * A {@link Form}component that creates a text field that allows for validation

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidatorBinding.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidatorBinding.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidatorBinding.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/valid/ValidatorBinding.java Mon Nov 13 22:02:23 2006
@@ -16,6 +16,7 @@
 
 import org.apache.hivemind.Location;
 import org.apache.hivemind.util.Defense;
+import org.apache.tapestry.IBinding;
 import org.apache.tapestry.binding.AbstractBinding;
 import org.apache.tapestry.coerce.ValueConverter;
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebActivator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebActivator.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebActivator.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebActivator.java Mon Nov 13 22:02:23 2006
@@ -17,7 +17,7 @@
 import org.apache.tapestry.describe.Describable;
 
 /**
- * A wrapper around a {@link javax.servlet.http.HttpServlet}&nbsp;or {@link *
+ * A wrapper around a {@link javax.servlet.http.HttpServlet}&nbsp;or 
  * {@link javax.portlet.Portlet}.
  * 
  * @author Howard M. Lewis Ship

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebContextResource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebContextResource.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebContextResource.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebContextResource.java Mon Nov 13 22:02:23 2006
@@ -17,6 +17,8 @@
 import java.net.URL;
 import java.util.Locale;
 
+import javax.servlet.ServletContext;
+
 import org.apache.hivemind.Resource;
 import org.apache.hivemind.util.AbstractResource;
 import org.apache.hivemind.util.LocalizedResource;

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebRequest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebRequest.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebSession.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebSession.java Mon Nov 13 22:02:23 2006
@@ -28,7 +28,7 @@
      * Returns a unique string identifier used to identify the session. This value is provided by
      * the container, and is typically incorporated into URLs, or stored as a HTTP cookie.
      * 
-     * @see org.apache.tapestry.web.WebResponse#encodeURL(String).
+     * @see org.apache.tapestry.web.WebResponse#encodeURL(String) .
      */
     String getId();
 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/asset/TestUnprotectedAsset.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/asset/TestUnprotectedAsset.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/asset/TestUnprotectedAsset.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/asset/TestUnprotectedAsset.java Mon Nov 13 22:02:23 2006
@@ -64,7 +64,6 @@
      * Creates {@link Pattern} objects for regexp matching.
      * 
      * @param pattern
-     * @return
      */
     protected Pattern newPattern(String pattern)
     {

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/components/TestIfElse.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/components/TestIfElse.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/components/TestIfElse.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/components/TestIfElse.java Mon Nov 13 22:02:23 2006
@@ -29,8 +29,8 @@
 import org.testng.annotations.Test;
 
 /**
- * Tests for {@link org.apache.tapestry.components.If}&nbsp;
- * and {@link org.apache.tapestry.components.Else}&nbsp;
+ * Tests for {@link org.apache.tapestry.components.IfBean}&nbsp;
+ * and {@link ElseBean}&nbsp;
  * components.
  * 
  * @author Mindbridge

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/dojo/form/DefaultAutocompleteModelTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/dojo/form/DefaultAutocompleteModelTest.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/dojo/form/DefaultAutocompleteModelTest.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/test/org/apache/tapestry/dojo/form/DefaultAutocompleteModelTest.java Mon Nov 13 22:02:23 2006
@@ -22,7 +22,7 @@
 
 
 /**
- * Tests functionality of {@link DefaultAutocompelteModel}.
+ * Tests functionality of {@link DefaultAutocompleteModel}.
  * 
  * @author jkuhnert
  */
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseDelegateFactory.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ResponseDelegateFactory.java Mon Nov 13 22:02:23 2006
@@ -16,10 +16,11 @@
 import java.io.IOException;
 
 import org.apache.tapestry.IRequestCycle;
+import org.apache.tapestry.engine.DirectService;
 
 
 /**
  * Service used by {@link AjaxDirectService} to determine type of ajax request
  * receive and determine the appropriate {@link ResponseBuilder} to handle
  * the response.
  *
@@ -16,10 +16,11 @@
 
 /**
- * Service used by {@link AjaxDirectService} to determine type of ajax request
+ * Service used by {@link DirectService} to determine type of ajax request
  * receive and determine the appropriate {@link ResponseBuilder} to handle
  * the response.

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ServiceConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/services/ServiceConstants.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================
--- tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebRequest.java (original)
+++ tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebRequest.java Mon Nov 13 22:02:23 2006
@@ -18,6 +18,8 @@
 import java.util.List;
 import java.util.Locale;
 
+import javax.servlet.http.HttpServletRequest;
+
 import org.apache.tapestry.describe.Describable;
 
 /**
@@ -194,7 +196,7 @@
     boolean isUserInRole(String role);
     
     /**
      * Taken from {@link HttpServletWebRequest}. Indicates if this request is coming in on
      * a SSL/secure connection. 
      * 
      * @return True if secure, false otherwise.
@@ -194,7 +196,7 @@
     
     /**
-     * Taken from {@link HttpServletWebRequest}. Indicates if this request is coming in on
+     * Taken from {@link HttpServletRequest}. Indicates if this request is coming in on
      * a SSL/secure connection. 
      * 

Modified: tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebSession.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry4/trunk/tapestry-framework/src/java/org/apache/tapestry/web/WebSession.java?view=diff&rev=474671&r1=474670&r2=474671
==============================================================================